@@ -17,6 +17,6 @@
 #' format_formula(model, "random")
 #' @export
 format_formula <- function(x, what = "conditional") {
-  f <- insight::safe_deparse(insight::find_formula(x)[[what]])
-  paste0("formula: ", paste0(f, collapse = " + "))
+  f <- insight::safe_deparse(insight::find_formula(x, verbose = FALSE)[[what]])
+  paste0("formula: ", paste(f, collapse = " + "))
 }
